@@ -5,6 +5,8 @@
 */
 
 #include "richtextcomposerimages.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "richtextcomposer.h"
 
 #include <KCodecs>
@@ -56,7 +58,7 @@ void RichTextComposerImages::addImageHelper(const QUrl &url, int width, int heig
         return;
     }
     const QFileInfo fi(url.path());
-    const QString imageName = fi.baseName().isEmpty() ? QStringLiteral("image.png") : QString(fi.baseName() + QLatin1String(".png"));
+    const QString imageName = fi.baseName().isEmpty() ? QStringLiteral("image.png") : QString(fi.baseName() + ".png"_L1);
     if (width != -1 && height != -1 && (image.width() > width && image.height() > height)) {
         image = image.scaled(width, height);
     }
@@ -198,7 +200,7 @@ QList<QTextImageFormat> RichTextComposerImages::embeddedImageFormats() const
                 if (imageFormat.isValid()) {
                     // TODO: Replace with a way to see if an image is an embedded image or a remote
                     const QUrl url(imageFormat.name());
-                    if (!url.isValid() || !url.scheme().startsWith(QLatin1String("http"))) {
+                    if (!url.isValid() || !url.scheme().startsWith("http"_L1)) {
                         retList.append(imageFormat);
                     }
                 }
@@ -219,7 +221,7 @@ QByteArray RichTextComposerImages::imageNamesToContentIds(const QByteArray &html
 {
     QByteArray result = htmlBody;
     for (const QSharedPointer<EmbeddedImage> &image : imageList) {
-        const QString newImageName = QLatin1String("cid:") + image->contentID;
+        const QString newImageName = "cid:"_L1 + image->contentID;
         QByteArray quote("\"");
         result.replace(QByteArray(quote + image->imageName.toLocal8Bit() + quote), QByteArray(quote + newImageName.toLocal8Bit() + quote));
     }
